@@ -1,4 +1,21 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2008,2009 Sebastian Pölsterl
+#
+# This file is part of GNOME DVB Daemon.
+#
+# GNOME DVB Daemon is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# GNOME DVB Daemon is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
+
 import gtk
 import pango
 import gobject
@@ -6,11 +23,14 @@ from gettext import gettext as _
 import gnomedvb
 from gnomedvb.ui.widgets.ChannelsStore import ChannelsStore
 from gnomedvb.ui.widgets.ChannelsView import ChannelsView
+from gnomedvb.ui.widgets.RunningNextStore import RunningNextStore
+from gnomedvb.ui.widgets.RunningNextView import RunningNextView
 from gnomedvb.ui.widgets.ScheduleStore import ScheduleStore
 from gnomedvb.ui.widgets.ScheduleView import ScheduleView
 from gnomedvb.ui.timers.EditTimersDialog import EditTimersDialog
 from gnomedvb.ui.timers.TimerDialog import NoTimerCreatedDialog
 from gnomedvb.ui.preferences.Preferences import Preferences
+from gnomedvb.ui.recordings.RecordingsDialog import RecordingsDialog
 
 class HelpBox(gtk.EventBox):
 
@@ -36,9 +56,14 @@ class ControlCenterWindow(gtk.Window):
     def __init__(self, model):
         gtk.Window.__init__(self)
         
+        self.runningnextstore = None
+        self.scrolledrunningnext = None
+        self.runningnextview = None
+        
         self.channellists = {}
         self.manager = model
-        self.manager.connect('changed', self._on_manager_changed)
+        self.manager.connect('group-added', self._on_manager_group_added)
+        self.manager.connect('group-removed', self._on_manager_group_removed)
         
         self.connect('delete-event', gtk.main_quit)
         self.connect('destroy-event', gtk.main_quit)
@@ -68,7 +93,7 @@ class ControlCenterWindow(gtk.Window):
         groups_label = gtk.Label(_("Device groups:"))
         self.vbox_left.pack_start(groups_label, False)
         
-        self.devgroupslist = gtk.ListStore(str, int)
+        self.devgroupslist = gtk.ListStore(str, int, gobject.TYPE_PYOBJECT)
         self.devgroupslist.connect("row-inserted", self._on_devgroupslist_inserted)
         
         self.devgroupscombo = gtk.ComboBox(self.devgroupslist)
@@ -96,7 +121,8 @@ class ControlCenterWindow(gtk.Window):
                 
         self.help_eventbox = HelpBox()
         self.choose_group_text = _("Choose a device group and channel on the left to view the program guide")
-        self.create_group_text = _("No device groups are configured. Please go to preferences and create one.")
+        self.create_group_text = _("No devices are configured. Please go to preferences and to configure them.")
+        self.no_events_text = _("There is currently no schedule available for this channel")
         self.hpaned.pack2(self.help_eventbox)
         
         self.scheduleview = ScheduleView()
@@ -120,6 +146,7 @@ class ControlCenterWindow(gtk.Window):
         <menubar name="MenuBar">
           <menu action="Timers">
             <menuitem action="EditTimers"/>
+            <menuitem action="Recordings"/>
             <separator/>
             <menuitem action="Quit"/>
           </menu>
@@ -127,6 +154,7 @@ class ControlCenterWindow(gtk.Window):
             <menuitem action="Preferences"/>
           </menu>
           <menu action="View">
+            <menuitem action="WhatsOnNow"/>
             <menuitem action="Refresh"/>
             <menuitem action="PrevDay"/>
             <menuitem action="NextDay"/>
@@ -148,7 +176,7 @@ class ControlCenterWindow(gtk.Window):
         # Create actions
         actiongroup = gtk.ActionGroup('Root')
         actiongroup.add_actions([
-            ('Timers', None, _('_Timers')),
+            ('Timers', None, _('_Recording schedule')),
             ('Edit', None, _('_Edit')),
             ('View', None, _('_View')),
             ('Help', None, _('Help')),
@@ -159,7 +187,9 @@ class ControlCenterWindow(gtk.Window):
         actiongroup = gtk.ActionGroup('Timers')
         actiongroup.add_actions([
             ('EditTimers', None, _('_Manage'), None,
-             _('Manage timers'), self._on_button_display_timers_clicked),
+             _('Manage recording schedule'), self._on_button_display_timers_clicked),
+            ('Recordings', None, _('_Recordings'), None,
+             _('Manage recordings'), self._on_button_recordings_clicked),
             ('Quit', gtk.STOCK_QUIT, _('_Quit'), None,
              _('Quit the Program'), gtk.main_quit)])
         uimanager.insert_action_group(actiongroup, 1)
@@ -173,6 +203,8 @@ class ControlCenterWindow(gtk.Window):
         
         actiongroup = gtk.ActionGroup('View')
         actiongroup.add_actions([
+            ('WhatsOnNow', None, _("What's on now"), None,
+             _("See what's currently on and is coming next"), self._on_whats_on_now_clicked),
             ('Refresh', gtk.STOCK_REFRESH, _('Refresh'), None,
              _('Refresh program guide'), self._on_refresh_clicked),
             ('PrevDay', None, _('Previous Day'), '<Control>B',
@@ -213,6 +245,19 @@ class ControlCenterWindow(gtk.Window):
         self.timersitem.set_image(timers_image)
         self.timersitem.set_sensitive(False)
         
+        pixbuf = icon_theme.load_icon("video", gtk.ICON_SIZE_MENU, gtk.ICON_LOOKUP_USE_BUILTIN)
+        recordings_image = gtk.image_new_from_pixbuf(pixbuf)
+        recordings_image.show()
+        
+        recordings = uimanager.get_widget('/MenuBar/Timers/Recordings')
+        recordings.set_image(recordings_image)
+        
+        whatson_image = gtk.image_new_from_stock(gtk.STOCK_INDEX, gtk.ICON_SIZE_MENU)
+        whatson_image.show()
+        
+        whatons_item = uimanager.get_widget('/MenuBar/View/WhatsOnNow')
+        whatons_item.set_image(whatson_image)
+        
         self.refresh_menuitem = uimanager.get_widget('/MenuBar/View/Refresh')
         self.refresh_menuitem.set_sensitive(False)
         
@@ -244,22 +289,42 @@ class ControlCenterWindow(gtk.Window):
         timers_image = gtk.image_new_from_pixbuf(pixbuf)
         timers_image.show()
         
-        self.button_display_timers = gtk.ToolButton(icon_widget=timers_image, label=_("Timers"))
+        self.button_display_timers = gtk.ToolButton(icon_widget=timers_image, label=_("Recording schedule"))
+        self.button_display_timers.set_is_important(True)
         self.button_display_timers.set_sensitive(False)
         self.button_display_timers.connect("clicked", self._on_button_display_timers_clicked)
-        self.button_display_timers.set_tooltip_markup(_("Manage timers"))
+        self.button_display_timers.set_tooltip_markup(_("Manage recording schedule"))
         self.button_display_timers.show()
         self.toolbar.insert(self.button_display_timers, 0)
         
+        pixbuf = icon_theme.load_icon("video", gtk.ICON_SIZE_MENU, gtk.ICON_LOOKUP_USE_BUILTIN)
+        recordings_image = gtk.image_new_from_pixbuf(pixbuf)
+        recordings_image.show()
+        
+        button_recordings = gtk.ToolButton(icon_widget=recordings_image, label=_("Recordings"))
+        button_recordings.set_is_important(True)
+        button_recordings.connect("clicked", self._on_button_recordings_clicked)
+        button_recordings.show()
+        self.toolbar.insert(button_recordings, 1)
+        
+        whatson_image = gtk.image_new_from_stock(gtk.STOCK_INDEX, gtk.ICON_SIZE_LARGE_TOOLBAR)
+        whatson_image.show()
+        
+        button_whatson = gtk.ToolButton(icon_widget=whatson_image, label=_("What's on now"))
+        button_whatson.set_is_important(True)
+        button_whatson.connect("clicked", self._on_whats_on_now_clicked)
+        button_whatson.show()
+        self.toolbar.insert(button_whatson, 2)
+         
         sep = gtk.SeparatorToolItem()
         sep.show()
-        self.toolbar.insert(sep, 1)
+        self.toolbar.insert(sep, 3)
         
         self.refresh_button = gtk.ToolButton(gtk.STOCK_REFRESH)
         self.refresh_button.connect("clicked", self._on_refresh_clicked)
         self.refresh_button.set_tooltip_markup(_("Refresh program guide"))        
         self.refresh_button.show()
-        self.toolbar.insert(self.refresh_button, 2)
+        self.toolbar.insert(self.refresh_button, 4)
         
         prev_image = gtk.image_new_from_stock(gtk.STOCK_GO_BACK, gtk.ICON_SIZE_LARGE_TOOLBAR)
         prev_image.show()
@@ -268,7 +333,7 @@ class ControlCenterWindow(gtk.Window):
         self.button_prev_day.set_tooltip_markup(_("Go to previous day"))
         self.button_prev_day.set_sensitive(False)
         self.button_prev_day.show()
-        self.toolbar.insert(self.button_prev_day, 3)
+        self.toolbar.insert(self.button_prev_day, 5)
         
         next_image = gtk.image_new_from_stock(gtk.STOCK_GO_FORWARD, gtk.ICON_SIZE_LARGE_TOOLBAR)
         next_image.show()
@@ -277,22 +342,21 @@ class ControlCenterWindow(gtk.Window):
         self.button_next_day.set_tooltip_markup(_("Go to next day"))
         self.button_next_day.set_sensitive(False)
         self.button_next_day.show()
-        self.toolbar.insert(self.button_next_day, 4)
-         
+        self.toolbar.insert(self.button_next_day, 6)
+        
     def get_device_groups(self):
-        for group in self.manager.get_registered_device_groups():
-            self._append_group(group)
-            
-    def device_groups_reply(self, a):
-        print a
-       
+        def append_groups(groups):
+            for group in groups:
+                self._append_group(group)
+        self.manager.get_registered_device_groups(reply_handler=append_groups)
+    
     def _select_first_group(self):
         self.devgroupscombo.set_active(0)
         self.channelsview.grab_focus()
            
     def _append_group(self, group):
-        self.devgroupslist.append([group["name"], group["id"]])
-        self.channellists[group["id"]] = gnomedvb.DVBChannelListClient(group["id"])
+        self.devgroupslist.append([group["name"], group["id"], group])
+        self.channellists[group["id"]] = group.get_channel_list()
         
     def _remove_group(self, group_id):
         aiter = None
@@ -301,7 +365,7 @@ class ControlCenterWindow(gtk.Window):
                 aiter = row.iter
                 
         if aiter != None:
-            if self._get_selected_group_id() == group_id:
+            if self._get_selected_group()["id"] == group_id:
                 # Select no group
                 self.devgroupscombo.set_active(-1)
                 
@@ -311,29 +375,31 @@ class ControlCenterWindow(gtk.Window):
     def _reset_ui(self):
         self.channelsstore = None
         self.channelsview.set_model(None)
-        self._reset_schedule_view()
+        if len(self.devgroupslist) == 0:
+            text = self.create_group_text
+        else:
+            text = self.choose_group_text
+        self._display_help_message(text)
         self._set_timers_sensitive(False)
         
     def _reset_schedule_view(self):
         self.schedulestore = None
         self.scheduleview.set_model(None)
-        self._display_help_message()
+        self._display_running_next()
 
-    def _on_manager_changed(self, manager, group_id, change_type):
-        if change_type == 0:
-            # added
-            group = self.manager.get_device_group(group_id)
-            self._append_group(group)
-        elif change_type == 1:
-            # deleted
-            self._remove_group(group_id)
+    def _on_manager_group_added(self, manager, group_id):
+        group = self.manager.get_device_group(group_id)
+        self._append_group(group)
+        
+    def _on_manager_group_removed(self, manager, group_id):
+        self._remove_group(group_id)
             
-    def _get_selected_group_id(self):
+    def _get_selected_group(self):
         aiter = self.devgroupscombo.get_active_iter()
         if aiter == None:
             return None
         else:
-            return self.devgroupslist[aiter][1]
+            return self.devgroupslist[aiter][2]
         
     def _get_selected_channel_sid(self):
         model, aiter = self.channelsview.get_selection().get_selected()
@@ -344,11 +410,11 @@ class ControlCenterWindow(gtk.Window):
             return None
     
     def _on_devgroupscombo_changed(self, combo):
-        group_id = self._get_selected_group_id()
-        if group_id != None:
+        group = self._get_selected_group()
+        if group != None:
             self._set_timers_sensitive(True)
             
-            self.channelsstore = ChannelsStore(group_id)
+            self.channelsstore = ChannelsStore(group)
             self.channelsview.set_model(self.channelsstore)
             
             self._reset_schedule_view()
@@ -365,10 +431,12 @@ class ControlCenterWindow(gtk.Window):
         child = self.hpaned.get_child2()
         if aiter != None:
             sid = model[aiter][model.COL_SID]
-            group_id = self._get_selected_group_id()
-            self.schedulestore = ScheduleStore(self.manager.get_schedule(group_id, sid))
+            group = self._get_selected_group()
+            self.schedulestore = ScheduleStore(group, sid)
+            self.schedulestore.connect("loading-finished",
+                self._on_schedule_loading_finished)
+                
             self.scheduleview.set_model(self.schedulestore)
-            
             # Display schedule if it isn't already displayed
             if child != self.scrolledschedule:
                 self.hpaned.remove(child)
@@ -377,11 +445,15 @@ class ControlCenterWindow(gtk.Window):
                 self._set_next_day_sensitive(True)
                 self._set_refresh_sensitive(True)
         else:
-            # Display help message if it isn't already displayed
-            if child != self.help_eventbox:
-                self._display_help_message()
-                
-    def _display_help_message(self):
+            # Display running/next if it isn't already displayed
+            if child != self.scrolledrunningnext:
+                self._display_running_next()
+    
+    def _on_schedule_loading_finished(self, schedulestore):
+        if len(self.schedulestore) == 0:
+            self._display_help_message(self.no_events_text)
+            
+    def _display_help_message(self, text):
         child = self.hpaned.get_child2()
         self.hpaned.remove(child)
         self.hpaned.pack2(self.help_eventbox)
@@ -389,10 +461,28 @@ class ControlCenterWindow(gtk.Window):
         self._set_next_day_sensitive(False)
         self._set_refresh_sensitive(False)
         
-        if len(self.devgroupslist) == 0:
-            self.help_eventbox.set_markup(self.create_group_text)
-        else:
-            self.help_eventbox.set_markup(self.choose_group_text)
+        self.help_eventbox.set_markup(text)
+     
+    def _display_running_next(self):
+        group = self._get_selected_group()
+        
+        self.runningnextstore = RunningNextStore(group)
+        
+        self.scrolledrunningnext = gtk.ScrolledWindow()
+        self.scrolledrunningnext.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        self.scrolledrunningnext.set_shadow_type(gtk.SHADOW_IN)
+        self.scrolledrunningnext.show()
+        
+        self.runningnextview = RunningNextView(self.runningnextstore)
+        self.runningnextview.show()
+        self.scrolledrunningnext.add(self.runningnextview)
+    
+        child = self.hpaned.get_child2()
+        self.hpaned.remove(child)
+        self.hpaned.pack2(self.scrolledrunningnext)
+        self._set_previous_day_sensitive(False)
+        self._set_next_day_sensitive(False)
+        self._set_refresh_sensitive(False)
                 
     def _set_next_day_sensitive(self, val):
         self.button_next_day.set_sensitive(val)
@@ -407,8 +497,8 @@ class ControlCenterWindow(gtk.Window):
         self.timersitem.set_sensitive(val)
         
     def _set_refresh_sensitive(self, val):
-       self.refresh_button.set_sensitive(val) 
-       self.refresh_menuitem.set_sensitive(val)
+        self.refresh_button.set_sensitive(val) 
+        self.refresh_menuitem.set_sensitive(val)
        
     def _on_event_selected(self, treeview, event):
         if event.type == gtk.gdk._2BUTTON_PRESS:
@@ -420,9 +510,9 @@ class ControlCenterWindow(gtk.Window):
                 dialog.set_markup (_("<big><span weight=\"bold\">Schedule recording for the selected event?</span></big>"))
                 if dialog.run() == gtk.RESPONSE_YES:
                     event_id = model[aiter][model.COL_EVENT_ID]
-                    group_id = self._get_selected_group_id()
+                    group = self._get_selected_group()
                     channel_sid = self._get_selected_channel_sid()
-                    recorder = gnomedvb.DVBRecorderClient(group_id)
+                    recorder = group.get_recorder()
                     rec_id = recorder.add_timer_for_epg_event(event_id, channel_sid)
                 dialog.destroy()
                 
@@ -432,12 +522,15 @@ class ControlCenterWindow(gtk.Window):
                     dialog.destroy()
         
     def _on_button_display_timers_clicked(self, button):
-        group_id = self._get_selected_group_id()
-        if group_id != None:
-            edit = EditTimersDialog(group_id, self)
+        group = self._get_selected_group()
+        if group != None:
+            edit = EditTimersDialog(group, self)
             edit.run()
             edit.destroy()
             
+    def _on_whats_on_now_clicked(self, button):
+        self._reset_schedule_view()
+            
     def _on_refresh_clicked(self, button):
         self.schedulestore.reload_all()
    
@@ -478,6 +571,11 @@ class ControlCenterWindow(gtk.Window):
         prefs.run()
         prefs.destroy()
         
+    def _on_button_recordings_clicked(self, button):
+        dialog = RecordingsDialog(self)
+        dialog.run()
+        dialog.destroy()
+        
     def _on_view_channels_clicked(self, action):
         if self.vbox_left:
             if action.get_active():
