@@ -17,12 +17,52 @@
  * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <src/Device.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <gio/gio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <gst/gst.h>
-#include "src/ChannelList.h"
 
 
+#define DVB_TYPE_ADAPTER_TYPE (dvb_adapter_type_get_type ())
 
+#define DVB_TYPE_DEVICE (dvb_device_get_type ())
+#define DVB_DEVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_DEVICE, DVBDevice))
+#define DVB_DEVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_DEVICE, DVBDeviceClass))
+#define DVB_IS_DEVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_DEVICE))
+#define DVB_IS_DEVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_DEVICE))
+#define DVB_DEVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_DEVICE, DVBDeviceClass))
+
+typedef struct _DVBDevice DVBDevice;
+typedef struct _DVBDeviceClass DVBDeviceClass;
+typedef struct _DVBDevicePrivate DVBDevicePrivate;
+
+#define DVB_TYPE_CHANNEL_LIST (dvb_channel_list_get_type ())
+#define DVB_CHANNEL_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL_LIST, DVBChannelList))
+#define DVB_CHANNEL_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL_LIST, DVBChannelListClass))
+#define DVB_IS_CHANNEL_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL_LIST))
+#define DVB_IS_CHANNEL_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL_LIST))
+#define DVB_CHANNEL_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL_LIST, DVBChannelListClass))
+
+typedef struct _DVBChannelList DVBChannelList;
+typedef struct _DVBChannelListClass DVBChannelListClass;
+
+typedef enum  {
+	DVB_ADAPTER_TYPE_UNKNOWN,
+	DVB_ADAPTER_TYPE_DVB_T,
+	DVB_ADAPTER_TYPE_DVB_S,
+	DVB_ADAPTER_TYPE_DVB_C
+} DVBAdapterType;
+
+struct _DVBDevice {
+	GObject parent_instance;
+	DVBDevicePrivate * priv;
+};
+
+struct _DVBDeviceClass {
+	GObjectClass parent_class;
+};
 
 struct _DVBDevicePrivate {
 	guint _Adapter;
@@ -33,6 +73,12 @@ struct _DVBDevicePrivate {
 	DVBAdapterType adapter_type;
 };
 
+
+static gpointer dvb_device_parent_class = NULL;
+
+GType dvb_adapter_type_get_type (void);
+GType dvb_device_get_type (void);
+GType dvb_channel_list_get_type (void);
 #define DVB_DEVICE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DVB_TYPE_DEVICE, DVBDevicePrivate))
 enum  {
 	DVB_DEVICE_DUMMY_PROPERTY,
@@ -44,11 +90,27 @@ enum  {
 	DVB_DEVICE_RECORDINGS_DIRECTORY
 };
 #define DVB_DEVICE_PRIME 31
-static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter, gboolean get_type);
 static void dvb_device_set_Adapter (DVBDevice* self, guint value);
 static void dvb_device_set_Frontend (DVBDevice* self, guint value);
-static gpointer dvb_device_parent_class = NULL;
+static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter, gboolean get_type);
+DVBDevice* dvb_device_new (guint adapter, guint frontend, gboolean get_type_and_name);
+DVBDevice* dvb_device_construct (GType object_type, guint adapter, guint frontend, gboolean get_type_and_name);
+void dvb_device_set_Channels (DVBDevice* self, DVBChannelList* value);
+void dvb_device_set_RecordingsDirectory (DVBDevice* self, GFile* value);
+DVBDevice* dvb_device_new_full (guint adapter, guint frontend, DVBChannelList* channels, GFile* recordings_dir);
+guint dvb_device_get_Adapter (DVBDevice* self);
+guint dvb_device_get_Frontend (DVBDevice* self);
+gboolean dvb_device_equal (DVBDevice* dev1, DVBDevice* dev2);
+guint dvb_device_hash_without_device (guint adapter, guint frontend);
+guint dvb_device_hash (DVBDevice* device);
+gboolean dvb_device_is_busy (DVBDevice* self);
+DVBAdapterType dvb_device_get_Type (DVBDevice* self);
+const char* dvb_device_get_Name (DVBDevice* self);
+DVBChannelList* dvb_device_get_Channels (DVBDevice* self);
+GFile* dvb_device_get_RecordingsDirectory (DVBDevice* self);
 static void dvb_device_finalize (GObject* obj);
+static void dvb_device_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
+static void dvb_device_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
@@ -95,98 +157,112 @@ DVBDevice* dvb_device_new (guint adapter, guint frontend, gboolean get_type_and_
 
 
 DVBDevice* dvb_device_new_full (guint adapter, guint frontend, DVBChannelList* channels, GFile* recordings_dir) {
+	DVBDevice* result;
 	DVBDevice* dev;
 	g_return_val_if_fail (channels != NULL, NULL);
 	g_return_val_if_fail (recordings_dir != NULL, NULL);
 	dev = dvb_device_new (adapter, frontend, TRUE);
 	dvb_device_set_Channels (dev, channels);
 	dvb_device_set_RecordingsDirectory (dev, recordings_dir);
-	return dev;
+	result = dev;
+	return result;
 }
 
 
 gboolean dvb_device_equal (DVBDevice* dev1, DVBDevice* dev2) {
-	gboolean _tmp0;
-	gboolean _tmp2;
-	_tmp0 = FALSE;
+	gboolean result;
+	gboolean _tmp0_;
+	gboolean _tmp1_;
+	_tmp0_ = FALSE;
 	if (dev1 == NULL) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp0 = dev2 == NULL;
+		_tmp0_ = dev2 == NULL;
 	}
-	if (_tmp0) {
-		return FALSE;
+	if (_tmp0_) {
+		result = FALSE;
+		return result;
 	}
-	_tmp2 = FALSE;
+	_tmp1_ = FALSE;
 	if (dev1->priv->_Adapter == dev2->priv->_Adapter) {
-		_tmp2 = dev2->priv->_Frontend == dev2->priv->_Frontend;
+		_tmp1_ = dev2->priv->_Frontend == dev2->priv->_Frontend;
 	} else {
-		_tmp2 = FALSE;
+		_tmp1_ = FALSE;
 	}
-	return _tmp2;
+	result = _tmp1_;
+	return result;
 }
 
 
 guint dvb_device_hash (DVBDevice* device) {
+	guint result;
 	if (device == NULL) {
-		return (guint) 0;
+		result = (guint) 0;
+		return result;
 	}
-	return dvb_device_hash_without_device (device->priv->_Adapter, device->priv->_Frontend);
+	result = dvb_device_hash_without_device (device->priv->_Adapter, device->priv->_Frontend);
+	return result;
 }
 
 
 guint dvb_device_hash_without_device (guint adapter, guint frontend) {
-	return ((2 * DVB_DEVICE_PRIME) + (DVB_DEVICE_PRIME * adapter)) + frontend;
+	guint result;
+	result = ((2 * DVB_DEVICE_PRIME) + (DVB_DEVICE_PRIME * adapter)) + frontend;
+	return result;
 }
 
 
 gboolean dvb_device_is_busy (DVBDevice* self) {
+	gboolean result;
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp1;
+	GstElement* _tmp0_;
 	GstBus* bus;
 	gboolean busy_val;
-	gboolean _tmp7;
 	g_return_val_if_fail (self != NULL, FALSE);
 	dvbsrc = gst_element_factory_make ("dvbsrc", "text_dvbsrc");
 	if (dvbsrc == NULL) {
-		gboolean _tmp0;
 		g_critical ("Device.vala:84: Could not create dvbsrc element");
-		return (_tmp0 = TRUE, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp0);
+		result = TRUE;
+		(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
+		return result;
 	}
 	g_object_set ((GObject*) dvbsrc, "adapter", self->priv->_Adapter, NULL);
 	g_object_set ((GObject*) dvbsrc, "frontend", self->priv->_Frontend, NULL);
 	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new (""));
-	_tmp1 = NULL;
-	gst_bin_add (GST_BIN (pipeline), (_tmp1 = dvbsrc, (_tmp1 == NULL) ? NULL : gst_object_ref (_tmp1)));
+	_tmp0_ = NULL;
+	gst_bin_add (GST_BIN (pipeline), (_tmp0_ = dvbsrc, (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	busy_val = FALSE;
-	while (gst_bus_have_pending (bus)) {
+	while (TRUE) {
 		GstMessage* msg;
-		gboolean _tmp2;
-		msg = gst_bus_pop (bus);
-		_tmp2 = FALSE;
-		if (msg->type == GST_MESSAGE_ERROR) {
-			_tmp2 = msg->src == GST_OBJECT (dvbsrc);
-		} else {
-			_tmp2 = FALSE;
+		gboolean _tmp1_;
+		if (!gst_bus_have_pending (bus)) {
+			break;
 		}
-		if (_tmp2) {
+		msg = gst_bus_pop (bus);
+		_tmp1_ = FALSE;
+		if (msg->type == GST_MESSAGE_ERROR) {
+			_tmp1_ = msg->src == GST_OBJECT (dvbsrc);
+		} else {
+			_tmp1_ = FALSE;
+		}
+		if (_tmp1_) {
 			GError* gerror;
 			char* debug_text;
-			char* _tmp6;
-			char* _tmp5;
-			GError* _tmp4;
-			GError* _tmp3;
+			char* _tmp5_;
+			char* _tmp4_;
+			GError* _tmp3_;
+			GError* _tmp2_;
 			gerror = NULL;
 			debug_text = NULL;
-			_tmp6 = NULL;
-			_tmp5 = NULL;
-			_tmp4 = NULL;
-			_tmp3 = NULL;
-			(gst_message_parse_error (msg, &_tmp3, &_tmp5), gerror = (_tmp4 = _tmp3, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp4));
-			debug_text = (_tmp6 = _tmp5, debug_text = (g_free (debug_text), NULL), _tmp6);
+			_tmp5_ = NULL;
+			_tmp4_ = NULL;
+			_tmp3_ = NULL;
+			_tmp2_ = NULL;
+			(gst_message_parse_error (msg, &_tmp2_, &_tmp4_), gerror = (_tmp3_ = _tmp2_, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp3_));
+			debug_text = (_tmp5_ = _tmp4_, debug_text = (g_free (debug_text), NULL), _tmp5_);
 			g_debug ("Device.vala:106: Error tuning: %s; %s", gerror->message, debug_text);
 			busy_val = TRUE;
 			(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
@@ -195,56 +271,65 @@ gboolean dvb_device_is_busy (DVBDevice* self) {
 		(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 	}
 	gst_element_set_state (pipeline, GST_STATE_NULL);
-	return (_tmp7 = busy_val, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), _tmp7);
+	result = busy_val;
+	(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
+	(pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL));
+	(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
+	return result;
 }
 
 
 static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter, gboolean get_type) {
+	gboolean result;
 	GstElement* dvbsrc;
 	GstElement* pipeline;
-	GstElement* _tmp2;
+	GstElement* _tmp0_;
 	GstBus* bus;
 	gboolean success;
 	char* adapter_type;
-	gboolean _tmp10;
 	g_return_val_if_fail (self != NULL, FALSE);
 	if (!get_type) {
-		return TRUE;
+		result = TRUE;
+		return result;
 	}
 	dvbsrc = gst_element_factory_make ("dvbsrc", "test_dvbsrc");
 	if (dvbsrc == NULL) {
-		gboolean _tmp1;
 		g_critical ("Device.vala:122: Could not create dvbsrc element");
-		return (_tmp1 = FALSE, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), _tmp1);
+		result = FALSE;
+		(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
+		return result;
 	}
 	g_object_set ((GObject*) dvbsrc, "adapter", adapter, NULL);
 	pipeline = (GstElement*) ((GstPipeline*) gst_pipeline_new ("type_name"));
-	_tmp2 = NULL;
-	gst_bin_add (GST_BIN (pipeline), (_tmp2 = dvbsrc, (_tmp2 == NULL) ? NULL : gst_object_ref (_tmp2)));
+	_tmp0_ = NULL;
+	gst_bin_add (GST_BIN (pipeline), (_tmp0_ = dvbsrc, (_tmp0_ == NULL) ? NULL : gst_object_ref (_tmp0_)));
 	gst_element_set_state (pipeline, GST_STATE_READY);
 	bus = gst_element_get_bus (pipeline);
 	success = FALSE;
 	adapter_type = NULL;
-	while (gst_bus_have_pending (bus)) {
+	while (TRUE) {
 		GstMessage* msg;
-		gboolean _tmp3;
-		msg = gst_bus_pop (bus);
-		_tmp3 = FALSE;
-		if (msg->type == GST_MESSAGE_ELEMENT) {
-			_tmp3 = msg->src == GST_OBJECT (dvbsrc);
-		} else {
-			_tmp3 = FALSE;
+		gboolean _tmp1_;
+		if (!gst_bus_have_pending (bus)) {
+			break;
 		}
-		if (_tmp3) {
+		msg = gst_bus_pop (bus);
+		_tmp1_ = FALSE;
+		if (msg->type == GST_MESSAGE_ELEMENT) {
+			_tmp1_ = msg->src == GST_OBJECT (dvbsrc);
+		} else {
+			_tmp1_ = FALSE;
+		}
+		if (_tmp1_) {
 			const GstStructure* structure;
 			structure = msg->structure;
 			if (_vala_strcmp0 (gst_structure_get_name (structure), "dvb-adapter") == 0) {
-				char* _tmp4;
-				char* _tmp5;
-				_tmp4 = NULL;
-				adapter_type = (_tmp4 = g_strdup_printf ("%s", gst_structure_get_string (structure, "type")), adapter_type = (g_free (adapter_type), NULL), _tmp4);
-				_tmp5 = NULL;
-				self->priv->adapter_name = (_tmp5 = g_strdup_printf ("%s", gst_structure_get_string (structure, "name")), self->priv->adapter_name = (g_free (self->priv->adapter_name), NULL), _tmp5);
+				char* _tmp2_;
+				char* _tmp3_;
+				_tmp2_ = NULL;
+				adapter_type = (_tmp2_ = g_strdup_printf ("%s", gst_structure_get_string (structure, "type")), adapter_type = (g_free (adapter_type), NULL), _tmp2_);
+				_tmp3_ = NULL;
+				self->priv->adapter_name = (_tmp3_ = g_strdup_printf ("%s", gst_structure_get_string (structure, "name")), self->priv->adapter_name = (g_free (self->priv->adapter_name), NULL), _tmp3_);
 				success = TRUE;
 				(msg == NULL) ? NULL : (msg = (gst_message_unref (msg), NULL));
 				break;
@@ -253,18 +338,18 @@ static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter
 			if (msg->type == GST_MESSAGE_ERROR) {
 				GError* gerror;
 				char* debug;
-				char* _tmp9;
-				char* _tmp8;
-				GError* _tmp7;
-				GError* _tmp6;
+				char* _tmp7_;
+				char* _tmp6_;
+				GError* _tmp5_;
+				GError* _tmp4_;
 				gerror = NULL;
 				debug = NULL;
-				_tmp9 = NULL;
-				_tmp8 = NULL;
-				_tmp7 = NULL;
-				_tmp6 = NULL;
-				(gst_message_parse_error (msg, &_tmp6, &_tmp8), gerror = (_tmp7 = _tmp6, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp7));
-				debug = (_tmp9 = _tmp8, debug = (g_free (debug), NULL), _tmp9);
+				_tmp7_ = NULL;
+				_tmp6_ = NULL;
+				_tmp5_ = NULL;
+				_tmp4_ = NULL;
+				(gst_message_parse_error (msg, &_tmp4_, &_tmp6_), gerror = (_tmp5_ = _tmp4_, (gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL)), _tmp5_));
+				debug = (_tmp7_ = _tmp6_, debug = (g_free (debug), NULL), _tmp7_);
 				g_critical ("Device.vala:152: %s %s", gerror->message, debug);
 				(gerror == NULL) ? NULL : (gerror = (g_error_free (gerror), NULL));
 				debug = (g_free (debug), NULL);
@@ -286,13 +371,20 @@ static gboolean dvb_device_setAdapterTypeAndName (DVBDevice* self, guint adapter
 			}
 		}
 	}
-	return (_tmp10 = success, (dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL)), (pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL)), (bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL)), adapter_type = (g_free (adapter_type), NULL), _tmp10);
+	result = success;
+	(dvbsrc == NULL) ? NULL : (dvbsrc = (gst_object_unref (dvbsrc), NULL));
+	(pipeline == NULL) ? NULL : (pipeline = (gst_object_unref (pipeline), NULL));
+	(bus == NULL) ? NULL : (bus = (gst_object_unref (bus), NULL));
+	adapter_type = (g_free (adapter_type), NULL);
+	return result;
 }
 
 
 guint dvb_device_get_Adapter (DVBDevice* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Adapter;
+	result = self->priv->_Adapter;
+	return result;
 }
 
 
@@ -304,8 +396,10 @@ static void dvb_device_set_Adapter (DVBDevice* self, guint value) {
 
 
 guint dvb_device_get_Frontend (DVBDevice* self) {
+	guint result;
 	g_return_val_if_fail (self != NULL, 0U);
-	return self->priv->_Frontend;
+	result = self->priv->_Frontend;
+	return result;
 }
 
 
@@ -317,51 +411,99 @@ static void dvb_device_set_Frontend (DVBDevice* self, guint value) {
 
 
 DVBAdapterType dvb_device_get_Type (DVBDevice* self) {
+	DVBAdapterType result;
 	g_return_val_if_fail (self != NULL, 0);
-	return self->priv->adapter_type;
+	result = self->priv->adapter_type;
+	return result;
 }
 
 
 const char* dvb_device_get_Name (DVBDevice* self) {
+	const char* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->adapter_name;
+	result = self->priv->adapter_name;
+	return result;
 }
 
 
 DVBChannelList* dvb_device_get_Channels (DVBDevice* self) {
+	DVBChannelList* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_Channels;
+	result = self->priv->_Channels;
+	return result;
 }
 
 
 void dvb_device_set_Channels (DVBDevice* self, DVBChannelList* value) {
-	DVBChannelList* _tmp2;
-	DVBChannelList* _tmp1;
+	DVBChannelList* _tmp1_;
+	DVBChannelList* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_Channels = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_Channels = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "Channels");
 }
 
 
 GFile* dvb_device_get_RecordingsDirectory (DVBDevice* self) {
+	GFile* result;
 	g_return_val_if_fail (self != NULL, NULL);
-	return self->priv->_RecordingsDirectory;
+	result = self->priv->_RecordingsDirectory;
+	return result;
 }
 
 
 void dvb_device_set_RecordingsDirectory (DVBDevice* self, GFile* value) {
-	GFile* _tmp2;
-	GFile* _tmp1;
+	GFile* _tmp1_;
+	GFile* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_RecordingsDirectory = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_RecordingsDirectory = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : g_object_ref (_tmp0_)), (self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL)), _tmp1_);
 	g_object_notify ((GObject *) self, "RecordingsDirectory");
 }
 
 
+static void dvb_device_class_init (DVBDeviceClass * klass) {
+	dvb_device_parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (DVBDevicePrivate));
+	G_OBJECT_CLASS (klass)->get_property = dvb_device_get_property;
+	G_OBJECT_CLASS (klass)->set_property = dvb_device_set_property;
+	G_OBJECT_CLASS (klass)->finalize = dvb_device_finalize;
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_ADAPTER, g_param_spec_uint ("Adapter", "Adapter", "Adapter", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_FRONTEND, g_param_spec_uint ("Frontend", "Frontend", "Frontend", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_CHANNELS, g_param_spec_object ("Channels", "Channels", "Channels", DVB_TYPE_CHANNEL_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_RECORDINGS_DIRECTORY, g_param_spec_object ("RecordingsDirectory", "RecordingsDirectory", "RecordingsDirectory", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+}
+
+
+static void dvb_device_instance_init (DVBDevice * self) {
+	self->priv = DVB_DEVICE_GET_PRIVATE (self);
+}
+
+
+static void dvb_device_finalize (GObject* obj) {
+	DVBDevice * self;
+	self = DVB_DEVICE (obj);
+	(self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL));
+	(self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL));
+	self->priv->adapter_name = (g_free (self->priv->adapter_name), NULL);
+	G_OBJECT_CLASS (dvb_device_parent_class)->finalize (obj);
+}
+
+
+GType dvb_device_get_type (void) {
+	static GType dvb_device_type_id = 0;
+	if (dvb_device_type_id == 0) {
+		static const GTypeInfo g_define_type_info = { sizeof (DVBDeviceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_device_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBDevice), 0, (GInstanceInitFunc) dvb_device_instance_init, NULL };
+		dvb_device_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBDevice", &g_define_type_info, 0);
+	}
+	return dvb_device_type_id;
+}
+
+
 static void dvb_device_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	DVBDevice * self;
 	gpointer boxed;
@@ -415,46 +557,6 @@ static void dvb_device_set_property (GObject * object, guint property_id, const
 }
 
 
-static void dvb_device_class_init (DVBDeviceClass * klass) {
-	dvb_device_parent_class = g_type_class_peek_parent (klass);
-	g_type_class_add_private (klass, sizeof (DVBDevicePrivate));
-	G_OBJECT_CLASS (klass)->get_property = dvb_device_get_property;
-	G_OBJECT_CLASS (klass)->set_property = dvb_device_set_property;
-	G_OBJECT_CLASS (klass)->finalize = dvb_device_finalize;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_ADAPTER, g_param_spec_uint ("Adapter", "Adapter", "Adapter", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_FRONTEND, g_param_spec_uint ("Frontend", "Frontend", "Frontend", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_TYPE, g_param_spec_enum ("Type", "Type", "Type", DVB_TYPE_ADAPTER_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_NAME, g_param_spec_string ("Name", "Name", "Name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_CHANNELS, g_param_spec_object ("Channels", "Channels", "Channels", DVB_TYPE_CHANNEL_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), DVB_DEVICE_RECORDINGS_DIRECTORY, g_param_spec_object ("RecordingsDirectory", "RecordingsDirectory", "RecordingsDirectory", G_TYPE_FILE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-}
-
-
-static void dvb_device_instance_init (DVBDevice * self) {
-	self->priv = DVB_DEVICE_GET_PRIVATE (self);
-}
-
-
-static void dvb_device_finalize (GObject* obj) {
-	DVBDevice * self;
-	self = DVB_DEVICE (obj);
-	(self->priv->_Channels == NULL) ? NULL : (self->priv->_Channels = (g_object_unref (self->priv->_Channels), NULL));
-	(self->priv->_RecordingsDirectory == NULL) ? NULL : (self->priv->_RecordingsDirectory = (g_object_unref (self->priv->_RecordingsDirectory), NULL));
-	self->priv->adapter_name = (g_free (self->priv->adapter_name), NULL);
-	G_OBJECT_CLASS (dvb_device_parent_class)->finalize (obj);
-}
-
-
-GType dvb_device_get_type (void) {
-	static GType dvb_device_type_id = 0;
-	if (dvb_device_type_id == 0) {
-		static const GTypeInfo g_define_type_info = { sizeof (DVBDeviceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dvb_device_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DVBDevice), 0, (GInstanceInitFunc) dvb_device_instance_init, NULL };
-		dvb_device_type_id = g_type_register_static (G_TYPE_OBJECT, "DVBDevice", &g_define_type_info, 0);
-	}
-	return dvb_device_type_id;
-}
-
-
 static int _vala_strcmp0 (const char * str1, const char * str2) {
 	if (str1 == NULL) {
 		return -(str1 != str2);
